package Test::ConfigFromFile;
use Moose;

extends 'MooseX::App::Cmd';

1;
